@@ -22,6 +22,11 @@ from alchemite_apiclient.model.categorical_model_column_info import CategoricalM
 from alchemite_apiclient.model.categorical_model_column_info_all_of import CategoricalModelColumnInfoAllOf
 from alchemite_apiclient.model.categorical_prediction import CategoricalPrediction
 from alchemite_apiclient.model.categorical_result import CategoricalResult
+from alchemite_apiclient.model.column_group_batch_request import ColumnGroupBatchRequest
+from alchemite_apiclient.model.column_group_patch_request import ColumnGroupPatchRequest
+from alchemite_apiclient.model.column_group_request import ColumnGroupRequest
+from alchemite_apiclient.model.column_group_response import ColumnGroupResponse
+from alchemite_apiclient.model.column_group_response_all_of import ColumnGroupResponseAllOf
 from alchemite_apiclient.model.column_info import ColumnInfo
 from alchemite_apiclient.model.column_value import ColumnValue
 from alchemite_apiclient.model.column_value_nullable import ColumnValueNullable
